============================================================
Dictyostelium discoideum data bases (:mod:`dicty`)
============================================================

.. py:currentmodule:: Orange.bio.dicty

.. autoclass:: Orange.bio.dicty.PIPAx
   :members: __init__, genomes, get_data, mappings, result_types, results_list

.. autoclass:: Orange.bio.dicty.DictyExpress
   :members: __init__, objects, annotationTypes, annotations, get_data, search

Auxillary functionality
-----------------------

.. autoclass:: Orange.bio.dicty.CacheSQLite
    :members: __init__, list, contains, add, get, commit, clear

